from unittest import TestCase
from vaspwiki import vaspwiki
# The testme.py file is my first test file.
# Although it’s overkill for now, we’ll use a
# unittest.TestCase subclass to provide infrastructure for later development.

"""
Test method 1
to run this test
$ cd tests/
$ pip install nose
$ nosetests
"""

class TestPlaygroud(TestCase):
    def test_open_browser(self):
        requested_pattern = 'INCAR'
        if vaspwiki.help_function(requested_pattern):
            self.assertTrue(True)

# class TestConsole(TestCase):
#     def test_basic(self):
#         pass

"""
Test method 2

To integrate above with our setup.py,
and ensure that Nose is installed when we run the tests, we’ll add a few lines to setup():

setup(
    ...
    test_suite='nose.collector',
    tests_require=['nose'],
)

To run this tests, we can do by:

$ python setup.py test

We can also update the .travis.yml so that the travis CI will examine the unit test

add the following to the .travis.yml, pip install -r requirements.txt is used for
installation of the markdown and nose modules.
install:
  - pip install -r requirements.txt
# command to run tests
script:
      - pytest

Note that, the test scripts must begin with test_ like this current file named 'test_me.py'
"""



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Copyright (c) 2018, Yue-Wen FANG.
License: MIT License (see LICENSE for details)
"""


__author__ = 'Yue-Wen FANG'
__maintainer__ = "Yue-Wen FANG"
__email__ = 'fyuewen@gmail.com'
__license__ = 'MIT License'
__creation_date__= 'Dec. 27, 2018'

import webbrowser
import sys

index_wiki = "https://cms.mpi.univie.ac.at/wiki/index.php/"


def help_function(pattern):
    url = index_wiki + pattern
    newtab = 2
    webbrowser.get().open(url, new=newtab)


def main():
    pattern_list = sys.argv[1:]
    for pattern in pattern_list:
        help_function(pattern)


if __name__ == "__main__":
    main()


#! /usr/bin/env python3
from vaspwiki.version import __version__
from vaspwiki.version import __author__
from vaspwiki.version import __maintainer__
from vaspwiki.version import __release_data__
from vaspwiki.version import __license__

__all__ = ['vaspwiki']




#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Copyright (c) 2018, Yue-Wen FANG.
License: MIT License (see LICENSE for details)
"""


__author__ = 'Yue-Wen FANG'
__maintainer__ = "Yue-Wen FANG"
__email__ = 'fyuewen@gmail.com'
__license__ = 'MIT License'
__creation_date__= 'Dec. 27, 2018'

"""
This script is used for command line mode of vaspwiki through 'entry point'.
In this method, the relevant modules of the python scripts can be used as 
command.
"""

from vaspwiki import vaspwiki

def vaspwiki_command():
    vaspwiki.main()



from vaspwiki import __version__
import io
import os
try:
	from setuptools import setup
except ImportError:
	from distutils.core import setup

here = os.path.dirname(__file__)
readme_path = os.path.join(here, 'README.rst')
with io.open(readme_path, encoding='utf-8') as readme_file:
	long_description = readme_file.read()


def readme():
	with open('README.rst') as f:
		return (f.read())


setup(name='vaspwiki',
	  version='1.1.1',
	  description='The VASP manual',
	  long_description=long_description,
	  long_description_content_type='text/x-rst',
	  keywords='python vasp manual',
	  url='https://github.com/yw-fang/vaspwiki',
	  author='Yue-Wen FANG',
	  author_email='fyuewen@gmail.com',
	  license='MIT LICENSE',
	  packages=['vaspwiki'],
	  install_requires=[
	  ],
	  test_suite='nose.collector',
	  tests_require=['nose'],
	  entry_points = {
		  'console_scripts': ['vaspwiki=vaspwiki.vaspwiki_command:vaspwiki_command'],
	  },
	  include_package_data=True,
	  zip_safe=False)



#! /usr/bin/env python3

__version__ = '1.1.1'
__author__ = 'Yue-Wen FANG'
__maintainer__ = "Yue-Wen FANG"
__email__ = 'fyuewen@gmail.com'
__license__ = 'MIT License'
__release_data__= 'Dec. 27, 2018'